<?php
/**
 * @author Mart Mangus and Krister Viirsaar
 * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
 *
 * Authentication Plugin: Login with Estonian ID-card
 *
 * The authentication proccess has two steps:
 * 1. Get a token from id.hitsa.ee (by redirecting the browser)
 * 2. Authenticate the token and get the persons details from id-auth.hitsa.ee
 *
 */
if (!defined('MOODLE_INTERNAL')) {
    die('Direct access to this script is forbidden.');    ///  It must be included from a Moodle page
}

require_once($CFG->dirroot.'/lib/authlib.php');

class auth_plugin_est_id_card_hitsa extends auth_plugin_base {

    /** Constructor */
    function auth_plugin_est_id_card_hitsa() {
        $this->authtype = 'est_id_card_hitsa';
    }

    /** First step is to get token from id.hitsa.ee */
    function get_token() {
        global $DB, $CFG, $SESSION;
        $returnUrl = $CFG->wwwroot . '/auth/est_id_card_hitsa/login.php';
        $errorUrl = $CFG->wwwroot . '/login/?get_token_error=1';
        $goto = 'https://id.ttu.ee/?goto=' . $returnUrl . '&errorurl=' . $errorUrl;
        redirect($goto);
    }

    /** Second step is to authenticate the token in id-auth.hitsa.ee */
    function authenticate_token($token) {
        global $CFG;
        $curl = curl_init();
        curl_setopt_array($curl, array(
            CURLOPT_URL => 'https://id-auth.ttu.ee?token=' . $token,
            CURLOPT_RETURNTRANSFER => true,
        ));

        $data = curl_exec($curl);
        if(!$data || curl_error($curl)) {
            if ($CFG->debug == DEBUG_DEVELOPER) {
                die('Error: "' . curl_error($curl) . '" - Code: ' . curl_errno($curl));
            }
            curl_close($curl);
            redirect($CFG->wwwroot . '/login/?curl_error=1');
        }
        curl_close($curl);
        return $data;
    }

    /** Parses data and returns idnumber */
    function get_id_number($data) {
        global $CFG;
        $expression = '~/serialNumber=([0-9]{11})~';
        if (preg_match($expression, $data, $matches))
            return $matches[1];
        else
            redirect($CFG->wwwroot . '/login/?get_id_error=1');
    }

    /** If all goes well and we have the idnumber of the person, log in. */
    function login($idnumber) {
        global $DB, $CFG, $SESSION;
        $conditions = array('idnumber' => $idnumber);
        $usertologin = $DB->get_record('user', $conditions, $fields='*');
        if ($usertologin !== false) {
            $USER = complete_user_login($usertologin);
			$SESSION->specialLogin = true;
            if (optional_param('password_recovery', false, PARAM_BOOL))
                $SESSION->wantsurl = $CFG->wwwroot . '/login/change_password.php';
            $goto = isset($SESSION->wantsurl) ? $SESSION->wantsurl : $CFG->wwwroot;
            redirect($goto);
        } else
            redirect($CFG->wwwroot . '/login/?no_user_with_id=1');
    }
	
	    function user_login($username, $password) {
        return false;
    }

    /** Creates "login with ID-card" link to Moodle login page */
    /*function loginpage_idp_list($wantsurl) {
        global $CFG;
        return array(
            array(
                'url' => new moodle_url($CFG->wwwroot . '/auth/est_id_card_hitsa/login.php'),
                //'icon' => new pix_icon('idkaart', 'Login with Estonian ID-card'),
				'iconurl' => new moodle_url($CFG->wwwroot. '/pix/idkaart.gif'),
                    // Need to copy this file (cp auth/est_id_card_hitsa/images/idkaart.gif pix/)
                'name' => get_string('login_with', 'auth_est_id_card_hitsa')
            )
        );
    }*/

    /** Shows nice error messages to user */
    function loginpage_hook() {
        global $errormsg;
        if (optional_param('no_user_with_id', false, PARAM_BOOL)) {
            $errormsg = get_string('no_user_with_id', 'auth_est_id_card_hitsa');
        } else if (optional_param('curl_error', false, PARAM_BOOL)) {
            $errormsg = get_string('curl_error', 'auth_est_id_card_hitsa');
        } else if (optional_param('get_id_error', false, PARAM_BOOL)) {
            $errormsg = get_string('get_id_error', 'auth_est_id_card_hitsa');
        } else if (optional_param('get_token_error', false, PARAM_BOOL)) {
            $errormsg = get_string('get_token_error', 'auth_est_id_card_hitsa');
            if ($CFG->debug == DEBUG_DEVELOPER) {
                die($_GET['errormessage']);
            }
        }
    }
}

