<?php
function block_my_courses_and_categories_get_courses() {
    global $CFG, $USER;

    $sortorder = 'fullname ASC';
    $enrolledcourses = enrol_get_my_courses(NULL, $sortorder);

    if(empty($enrolledcourses)) {
        return null;
    }

    $courses = array();
    $courses['studying'] = array();
    $courses['teaching'] = array();
    $courses['categories'] = array();
    $courses['showmores'] = array();
    $alreadyexisting = array();

    $count_c = 0;
    $count_t = 0;
    $count_s = 0;
    foreach($enrolledcourses as $id => $course) {
        if($course->visible == 0) {
            continue;
        }

        // Get course's root category
        $rootcategory = get_root_category($course->category);

        if($count_c < 5) {
            $display = 'block';
        } else {
            $display = 'none';
            $courses['showmores']['categories'] = get_string('show_more', 'block_my_courses_and_categories');
        }

        $categorydoesntexist = array_key_exists($rootcategory->id, $alreadyexisting);
        if(!$categorydoesntexist) {
            $category = array(
                'id' => $rootcategory->id,
                'name' => $rootcategory->name,
                'link' => "$CFG->wwwroot/course/index.php?categoryid=$rootcategory->id",
                'display' => $display
            );
            $courses['categories'][] = $category;
            $alreadyexisting[$rootcategory->id] = $rootcategory->name;
            $count_c++;
        }

        // Sort course to list by userrole.
        $context = context_course::instance($id);
        $userroles = get_user_roles($context, $USER->id);

        foreach ($userroles as $role) {
            $newcourse = array(
                'id' => $course->id,
                'name' => $course->fullname,
                'link' => "$CFG->wwwroot/course/view.php?id=$course->id",
                'starttime' => $course->startdate
            );
            if($role->shortname == 'student') {
                if($count_s < 5) {
                    $newcourse['display'] = 'block';
                } else {
                    $newcourse['display'] = 'none';
                    $courses['showmores']['studying'] = get_string('show_more', 'block_my_courses_and_categories');
                }
                $courses['studying'][] = $newcourse;
                $count_s++;
            } elseif($role->shortname == 'editingteacher' || $role->shortname == 'teacher') {
                if($count_t < 5) {
                    $newcourse['display'] = 'block';
                } else {
                    $newcourse['display'] = 'none';
                    $courses['showmores']['teaching'] = get_string('show_more', 'block_my_courses_and_categories');
                }
                $courses['teaching'][] = $newcourse;
                $count_t++;
            }
        }
    }

    // Sort categories alphabetically by name.
    usort($courses['categories'], function($a, $b) {
        return strcmp($a['name'], $b['name']);
    });

    return $courses;
}

function get_root_category($id) {
    global $DB;
    $category = $DB->get_record('course_categories', array('id' => $id));
    $path = explode('/', $category->path);
    $rootcategoryid = $path[1];
    $rootcategory = $DB->get_record('course_categories', array('id' => $rootcategoryid));
    return $rootcategory;
}

function attach_js($visiblebydefault) {
    $script = html_writer::start_tag('script', array('type' => 'text/javascript'));

    $expandedtxt = get_string('show_less', 'block_my_courses_and_categories');
    $collapsedtxt = get_string('show_more', 'block_my_courses_and_categories');

    $script .= "
    var expandedstring = '{$expandedtxt}';
    var collapsedstring = '{$collapsedtxt}';
    var studyingCollapsed, teachingCollapsed, schoolsCollapsed = true;

    function showHide(elementToHide, hiderId) {
        var showHideElement = document.getElementById(hiderId);
        var listElement = document.getElementById(elementToHide);
        var listElementChildren = listElement.children;

        var idPrefix = elementToHide.replace('_show_more', '');

        if(window[idPrefix + 'Collapsed']) {
            for(var i = {$visiblebydefault}; i < listElementChildren.length; i++) {
                listElementChildren[i].style.display = 'none';
            }
            showHideElement.innerHTML = collapsedstring;
            window[idPrefix + 'Collapsed'] = false;
        } else {
            for(var i = {$visiblebydefault}; i < listElementChildren.length; i++) {
                listElementChildren[i].style.display = 'block';
            }
            showHideElement.innerHTML = expandedstring;
            window[idPrefix + 'Collapsed'] = true;
        }
    }
    ";

    $script .= html_writer::end_tag('script');

    return $script;
}
