<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Admin Bookmarks Block page.
 *
 * @package    block
 * @subpackage searchcourses
 * @copyright  University of Bath 2013
 * @author      Hittesh Ahuja
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 *
 */

require_once('localfunctions.php');

/**
 * The Search Courses Autocomplete block class
 */
class block_searchcourses extends block_base
{
    public function init()
    {
        $this->title = get_string('pluginname', 'block_searchcourses');
    }
    
    private function autocomplete_js()
    {
        global $PAGE, $CFG;
        $autocomplete = $CFG->wwwroot . '/blocks/searchcourses/js/module.js';
        $url          = new moodle_url($autocomplete);
        return $PAGE->requires->js($url);
    }

    public function applicable_formats()
    {
        return array(
            'site' => true,
            'course-view' => true,
            'site-index' => true,
            'my' => true,
	        'course-index' => true
        );
    }

    public function get_content()
    {
        global $CFG, $PAGE, $rootcategories;
	    require_once($CFG->libdir.'/coursecatlib.php');

	    if ($this->content !== null) {
		    return $this->content;
	    }

        $this->content = new stdClass();
        $params = array();
        $count = "";
        $module = array(
            'name' => 'course_search_ac',
            'fullpath' => '/blocks/searchcourses/js/module.js'
        );

        if (!is_null($this->config)) {
            $params = array(
                'course_count' => $this->config->course_count
            );
            $this->page->requires->data_for_js('ac_course_count', array(
                'count' => $this->config->course_count
            ));
            $count = $this->config->course_count;
        }

	    search_courses_get_root_categories();

        $form_html = "";
        $form_html .= $this->page->requires->js_init_call('M.search_autocomplete.init', array($params), false, $module);
        $form_html .= "<div id='course_search_ac'>";
        $form_html .= "<label for='ac-input'>". get_string('search_label', 'block_searchcourses') ."</label>";
        $form_html .= "<input id='ac-input' type='text' title=". get_string('helptext', 'block_searchcourses') ."> </input>";

        $form_html .= "<div id='filter_container'>";

        $form_html .= "<div id='my_courses_container'>";
        $form_html .= "<label for='my_courses_flag'>". get_string('mycourses') ."</label>";
        $form_html .= "<input type='checkbox' id='my_courses_flag' name='my_courses_flag' value='0'".($PAGE->pagetype == 'my-index' ? 'checked' : '')." />";
        $form_html .= "</div>";

	    $form_html .= "<div id='only_active_container'>";
	    $form_html .= "<label for='only_active_flag'>". get_string('onlyactive', 'block_searchcourses') ."</label>";
	    $form_html .= "<input type='checkbox' id='only_active_flag' name='only_active_flag' value='0' checked />";
	    $form_html .= "</div>";

	    $form_html .= "<div id='root_categories_container'>";
	    $form_html .= "<label for='categories_select'>". get_string('category_select', 'block_searchcourses') ."</label>";
	    $form_html .= "<select id='categories_select' name='categories_select'>";
	    $form_html .= "<option value=''>".get_string('all_categories', 'block_searchcourses')."</option>";
	    foreach($rootcategories as $category)
	    	$form_html .= "<option value='{$category->id}'>{$category->name}</option>";
	    $form_html .= "</select>";
	    $form_html .= "</div>";

	    $form_html .= "</div>";

        $form_html .= "<input type='hidden' id='course_count' value='{$count}' />";
        $form_html .= "</div>";

        $this->content->text = $form_html;

        return $this->content;
    }
}
